(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', '@angular/common'], factory) :
	(factory((global.angularWalkthrough = global.angularWalkthrough || {}),global.ng.core,global.ng.common));
}(this, (function (exports,_angular_core,_angular_common) { 'use strict';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */
/* global Reflect, Promise */

var extendStatics = Object.setPrototypeOf ||
    ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
    function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };

function __extends(d, b) {
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}

/**
 * @license
 * Copyright Google Inc. All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * Throws an exception when attempting to attach a null portal to a host.
 * \@docs-private
 * @return {?}
 */
function throwNullPortalError() {
    throw Error('Must provide a portal to attach');
}
/**
 * Throws an exception when attempting to attach a portal to a host that is already attached.
 * \@docs-private
 * @return {?}
 */
function throwPortalAlreadyAttachedError() {
    throw Error('Host already has a portal attached');
}
/**
 * Throws an exception when attempting to attach a portal to an already-disposed host.
 * \@docs-private
 * @return {?}
 */
function throwPortalHostAlreadyDisposedError() {
    throw Error('This PortalHost has already been disposed');
}
/**
 * Throws an exception when attempting to attach an unknown portal type.
 * \@docs-private
 * @return {?}
 */
function throwUnknownPortalTypeError() {
    throw Error('Attempting to attach an unknown Portal type. BasePortalHost accepts either ' +
        'a ComponentPortal or a TemplatePortal.');
}
/**
 * Throws an exception when attempting to attach a portal to a null host.
 * \@docs-private
 * @return {?}
 */
function throwNullPortalHostError() {
    throw Error('Attempting to attach a portal to a null PortalHost');
}
/**
 * Throws an exception when attempting to detach a portal that is not attached.
 * \@docs-privatew
 * @return {?}
 */
function throwNoPortalAttachedError() {
    throw Error('Attempting to detach a portal that is not attached to a host');
}

/**
 * A `Portal` is something that you want to render somewhere else.
 * It can be attach to / detached from a `PortalHost`.
 * @abstract
 */
var Portal = (function () {
    function Portal() {
    }
    /**
     * Attach this portal to a host.
     * @param {?} host
     * @return {?}
     */
    Portal.prototype.attach = function (host) {
        if (host == null) {
            throwNullPortalHostError();
        }
        if (host.hasAttached()) {
            throwPortalAlreadyAttachedError();
        }
        this._attachedHost = host;
        return (host.attach(this));
    };
    /**
     * Detach this portal from its host
     * @return {?}
     */
    Portal.prototype.detach = function () {
        var /** @type {?} */ host = this._attachedHost;
        if (host == null) {
            throwNoPortalAttachedError();
        }
        else {
            this._attachedHost = null;
            host.detach();
        }
    };
    Object.defineProperty(Portal.prototype, "isAttached", {
        /**
         * Whether this portal is attached to a host.
         * @return {?}
         */
        get: function () {
            return this._attachedHost != null;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Sets the PortalHost reference without performing `attach()`. This is used directly by
     * the PortalHost when it is performing an `attach()` or `detach()`.
     * @param {?} host
     * @return {?}
     */
    Portal.prototype.setAttachedHost = function (host) {
        this._attachedHost = host;
    };
    return Portal;
}());
/**
 * A `ComponentPortal` is a portal that instantiates some Component upon attachment.
 */
var ComponentPortal = (function (_super) {
    __extends(ComponentPortal, _super);
    /**
     * @param {?} component
     * @param {?=} viewContainerRef
     * @param {?=} injector
     */
    function ComponentPortal(component, viewContainerRef, injector) {
        var _this = _super.call(this) || this;
        _this.component = component;
        _this.viewContainerRef = viewContainerRef;
        _this.injector = injector;
        return _this;
    }
    return ComponentPortal;
}(Portal));
/**
 * A `TemplatePortal` is a portal that represents some embedded template (TemplateRef).
 */
var TemplatePortal = (function (_super) {
    __extends(TemplatePortal, _super);
    /**
     * @param {?} template
     * @param {?} viewContainerRef
     * @param {?=} context
     */
    function TemplatePortal(template, viewContainerRef, context) {
        var _this = _super.call(this) || this;
        _this.templateRef = template;
        _this.viewContainerRef = viewContainerRef;
        if (context) {
            _this.context = context;
        }
        return _this;
    }
    Object.defineProperty(TemplatePortal.prototype, "origin", {
        /**
         * @return {?}
         */
        get: function () {
            return this.templateRef.elementRef;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Attach the the portal to the provided `PortalHost`.
     * When a context is provided it will override the `context` property of the `TemplatePortal`
     * instance.
     * @param {?} host
     * @param {?=} context
     * @return {?}
     */
    TemplatePortal.prototype.attach = function (host, context) {
        if (context === void 0) { context = this.context; }
        this.context = context;
        return _super.prototype.attach.call(this, host);
    };
    /**
     * @return {?}
     */
    TemplatePortal.prototype.detach = function () {
        this.context = undefined;
        return _super.prototype.detach.call(this);
    };
    return TemplatePortal;
}(Portal));
/**
 * Partial implementation of PortalHost that only deals with attaching either a
 * ComponentPortal or a TemplatePortal.
 * @abstract
 */
var BasePortalHost = (function () {
    function BasePortalHost() {
        /**
         * Whether this host has already been permanently disposed.
         */
        this._isDisposed = false;
    }
    /**
     * Whether this host has an attached portal.
     * @return {?}
     */
    BasePortalHost.prototype.hasAttached = function () {
        return !!this._attachedPortal;
    };
    /**
     * @param {?} portal
     * @return {?}
     */
    BasePortalHost.prototype.attach = function (portal) {
        if (!portal) {
            throwNullPortalError();
        }
        if (this.hasAttached()) {
            throwPortalAlreadyAttachedError();
        }
        if (this._isDisposed) {
            throwPortalHostAlreadyDisposedError();
        }
        if (portal instanceof ComponentPortal) {
            this._attachedPortal = portal;
            return this.attachComponentPortal(portal);
        }
        else if (portal instanceof TemplatePortal) {
            this._attachedPortal = portal;
            return this.attachTemplatePortal(portal);
        }
        throwUnknownPortalTypeError();
    };
    /**
     * @abstract
     * @template T
     * @param {?} portal
     * @return {?}
     */
    BasePortalHost.prototype.attachComponentPortal = function (portal) { };
    /**
     * @abstract
     * @template C
     * @param {?} portal
     * @return {?}
     */
    BasePortalHost.prototype.attachTemplatePortal = function (portal) { };
    /**
     * @return {?}
     */
    BasePortalHost.prototype.detach = function () {
        if (this._attachedPortal) {
            this._attachedPortal.setAttachedHost(null);
            this._attachedPortal = null;
        }
        this._invokeDisposeFn();
    };
    /**
     * @return {?}
     */
    BasePortalHost.prototype.dispose = function () {
        if (this.hasAttached()) {
            this.detach();
        }
        this._invokeDisposeFn();
        this._isDisposed = true;
    };
    /**
     * @param {?} fn
     * @return {?}
     */
    BasePortalHost.prototype.setDisposeFn = function (fn) {
        this._disposeFn = fn;
    };
    /**
     * @return {?}
     */
    BasePortalHost.prototype._invokeDisposeFn = function () {
        if (this._disposeFn) {
            this._disposeFn();
            this._disposeFn = null;
        }
    };
    return BasePortalHost;
}());

/**
 * A PortalHost for attaching portals to an arbitrary DOM element outside of the Angular
 * application context.
 *
 * This is the only part of the portal core that directly touches the DOM.
 */
var DomPortalHost = (function (_super) {
    __extends(DomPortalHost, _super);
    /**
     * @param {?} _hostDomElement
     * @param {?} _componentFactoryResolver
     * @param {?} _appRef
     * @param {?} _defaultInjector
     */
    function DomPortalHost(_hostDomElement, _componentFactoryResolver, _appRef, _defaultInjector) {
        var _this = _super.call(this) || this;
        _this._hostDomElement = _hostDomElement;
        _this._componentFactoryResolver = _componentFactoryResolver;
        _this._appRef = _appRef;
        _this._defaultInjector = _defaultInjector;
        return _this;
    }
    /**
     * Attach the given ComponentPortal to DOM element using the ComponentFactoryResolver.
     * @template T
     * @param {?} portal Portal to be attached
     * @return {?}
     */
    DomPortalHost.prototype.attachComponentPortal = function (portal) {
        var _this = this;
        var /** @type {?} */ componentFactory = this._componentFactoryResolver.resolveComponentFactory(portal.component);
        var /** @type {?} */ componentRef;
        // If the portal specifies a ViewContainerRef, we will use that as the attachment point
        // for the component (in terms of Angular's component tree, not rendering).
        // When the ViewContainerRef is missing, we use the factory to create the component directly
        // and then manually attach the view to the application.
        if (portal.viewContainerRef) {
            componentRef = portal.viewContainerRef.createComponent(componentFactory, portal.viewContainerRef.length, portal.injector || portal.viewContainerRef.parentInjector);
            this.setDisposeFn(function () { return componentRef.destroy(); });
        }
        else {
            componentRef = componentFactory.create(portal.injector || this._defaultInjector);
            this._appRef.attachView(componentRef.hostView);
            this.setDisposeFn(function () {
                _this._appRef.detachView(componentRef.hostView);
                componentRef.destroy();
            });
        }
        // At this point the component has been instantiated, so we move it to the location in the DOM
        // where we want it to be rendered.
        this._hostDomElement.appendChild(this._getComponentRootNode(componentRef));
        return componentRef;
    };
    /**
     * Attaches a template portal to the DOM as an embedded view.
     * @template C
     * @param {?} portal Portal to be attached.
     * @return {?}
     */
    DomPortalHost.prototype.attachTemplatePortal = function (portal) {
        var _this = this;
        var /** @type {?} */ viewContainer = portal.viewContainerRef;
        var /** @type {?} */ viewRef = viewContainer.createEmbeddedView(portal.templateRef, portal.context);
        viewRef.detectChanges();
        // The method `createEmbeddedView` will add the view as a child of the viewContainer.
        // But for the DomPortalHost the view can be added everywhere in the DOM (e.g Overlay Container)
        // To move the view to the specified host element. We just re-append the existing root nodes.
        viewRef.rootNodes.forEach(function (rootNode) { return _this._hostDomElement.appendChild(rootNode); });
        this.setDisposeFn((function () {
            var /** @type {?} */ index = viewContainer.indexOf(viewRef);
            if (index !== -1) {
                viewContainer.remove(index);
            }
        }));
        // TODO(jelbourn): Return locals from view.
        return viewRef;
    };
    /**
     * Clears out a portal from the DOM.
     * @return {?}
     */
    DomPortalHost.prototype.dispose = function () {
        _super.prototype.dispose.call(this);
        if (this._hostDomElement.parentNode != null) {
            this._hostDomElement.parentNode.removeChild(this._hostDomElement);
        }
    };
    /**
     * Gets the root HTMLElement for an instantiated component.
     * @param {?} componentRef
     * @return {?}
     */
    DomPortalHost.prototype._getComponentRootNode = function (componentRef) {
        return (((componentRef.hostView)).rootNodes[0]);
    };
    return DomPortalHost;
}(BasePortalHost));

/**
 * Directive version of a `TemplatePortal`. Because the directive *is* a TemplatePortal,
 * the directive instance itself can be attached to a host, enabling declarative use of portals.
 *
 * Usage:
 * <ng-template portal #greeting>
 *   <p> Hello {{name}} </p>
 * </ng-template>
 */
var TemplatePortalDirective = (function (_super) {
    __extends(TemplatePortalDirective, _super);
    /**
     * @param {?} templateRef
     * @param {?} viewContainerRef
     */
    function TemplatePortalDirective(templateRef, viewContainerRef) {
        return _super.call(this, templateRef, viewContainerRef) || this;
    }
    TemplatePortalDirective.decorators = [
        { type: _angular_core.Directive, args: [{
                    selector: '[cdk-portal], [cdkPortal], [portal]',
                    exportAs: 'cdkPortal',
                },] },
    ];
    /**
     * @nocollapse
     */
    TemplatePortalDirective.ctorParameters = function () { return [
        { type: _angular_core.TemplateRef, },
        { type: _angular_core.ViewContainerRef, },
    ]; };
    return TemplatePortalDirective;
}(TemplatePortal));
/**
 * Directive version of a PortalHost. Because the directive *is* a PortalHost, portals can be
 * directly attached to it, enabling declarative use.
 *
 * Usage:
 * <ng-template [cdkPortalHost]="greeting"></ng-template>
 */
var PortalHostDirective = (function (_super) {
    __extends(PortalHostDirective, _super);
    /**
     * @param {?} _componentFactoryResolver
     * @param {?} _viewContainerRef
     */
    function PortalHostDirective(_componentFactoryResolver, _viewContainerRef) {
        var _this = _super.call(this) || this;
        _this._componentFactoryResolver = _componentFactoryResolver;
        _this._viewContainerRef = _viewContainerRef;
        /**
         * The attached portal.
         */
        _this._portal = null;
        return _this;
    }
    Object.defineProperty(PortalHostDirective.prototype, "_deprecatedPortal", {
        /**
         * @deprecated
         * @return {?}
         */
        get: function () { return this.portal; },
        /**
         * @param {?} v
         * @return {?}
         */
        set: function (v) { this.portal = v; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PortalHostDirective.prototype, "portal", {
        /**
         * Portal associated with the Portal host.
         * @return {?}
         */
        get: function () {
            return this._portal;
        },
        /**
         * @param {?} portal
         * @return {?}
         */
        set: function (portal) {
            if (this.hasAttached()) {
                _super.prototype.detach.call(this);
            }
            if (portal) {
                _super.prototype.attach.call(this, portal);
            }
            this._portal = portal;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    PortalHostDirective.prototype.ngOnDestroy = function () {
        _super.prototype.dispose.call(this);
        this._portal = null;
    };
    /**
     * Attach the given ComponentPortal to this PortalHost using the ComponentFactoryResolver.
     *
     * @template T
     * @param {?} portal Portal to be attached to the portal host.
     * @return {?}
     */
    PortalHostDirective.prototype.attachComponentPortal = function (portal) {
        portal.setAttachedHost(this);
        // If the portal specifies an origin, use that as the logical location of the component
        // in the application tree. Otherwise use the location of this PortalHost.
        var /** @type {?} */ viewContainerRef = portal.viewContainerRef != null ?
            portal.viewContainerRef :
            this._viewContainerRef;
        var /** @type {?} */ componentFactory = this._componentFactoryResolver.resolveComponentFactory(portal.component);
        var /** @type {?} */ ref = viewContainerRef.createComponent(componentFactory, viewContainerRef.length, portal.injector || viewContainerRef.parentInjector);
        _super.prototype.setDisposeFn.call(this, function () { return ref.destroy(); });
        this._portal = portal;
        return ref;
    };
    /**
     * Attach the given TemplatePortal to this PortlHost as an embedded View.
     * @template C
     * @param {?} portal Portal to be attached.
     * @return {?}
     */
    PortalHostDirective.prototype.attachTemplatePortal = function (portal) {
        var _this = this;
        portal.setAttachedHost(this);
        var /** @type {?} */ viewRef = this._viewContainerRef.createEmbeddedView(portal.templateRef, portal.context);
        _super.prototype.setDisposeFn.call(this, function () { return _this._viewContainerRef.clear(); });
        this._portal = portal;
        return viewRef;
    };
    PortalHostDirective.decorators = [
        { type: _angular_core.Directive, args: [{
                    selector: '[cdkPortalHost], [portalHost]',
                    exportAs: 'cdkPortalHost',
                    inputs: ['portal: cdkPortalHost']
                },] },
    ];
    /**
     * @nocollapse
     */
    PortalHostDirective.ctorParameters = function () { return [
        { type: _angular_core.ComponentFactoryResolver, },
        { type: _angular_core.ViewContainerRef, },
    ]; };
    PortalHostDirective.propDecorators = {
        '_deprecatedPortal': [{ type: _angular_core.Input, args: ['portalHost',] },],
    };
    return PortalHostDirective;
}(BasePortalHost));
var PortalModule = (function () {
    function PortalModule() {
    }
    PortalModule.decorators = [
        { type: _angular_core.NgModule, args: [{
                    exports: [TemplatePortalDirective, PortalHostDirective],
                    declarations: [TemplatePortalDirective, PortalHostDirective],
                },] },
    ];
    /**
     * @nocollapse
     */
    PortalModule.ctorParameters = function () { return []; };
    return PortalModule;
}());

/**
 * Custom injector to be used when providing custom
 * injection tokens to components inside a portal.
 * \@docs-private
 */
var PortalInjector = (function () {
    /**
     * @param {?} _parentInjector
     * @param {?} _customTokens
     */
    function PortalInjector(_parentInjector, _customTokens) {
        this._parentInjector = _parentInjector;
        this._customTokens = _customTokens;
    }
    /**
     * @param {?} token
     * @param {?=} notFoundValue
     * @return {?}
     */
    PortalInjector.prototype.get = function (token, notFoundValue) {
        var /** @type {?} */ value = this._customTokens.get(token);
        if (typeof value !== 'undefined') {
            return value;
        }
        return this._parentInjector.get(token, notFoundValue);
    };
    return PortalInjector;
}());

var WalkthroughService = (function () {
    function WalkthroughService() {
        var _this = this;
        this._preventDefault = (function (e) {
            e = e || window.event;
            if (e.preventDefault) {
                e.preventDefault();
            }
            e.returnValue = false;
        }).bind(this);
        this._overflowRegex = /(auto|scroll)/;
        this._preventDefaultForScrollKeys = (function (e) {
            // spacebar: 32, pageup: 33, pagedown: 34, end: 35, home: 36, left: 37, up: 38, right: 39, down: 40
            if (e.keyCode >= 32 && e.keyCode <= 40) {
                _this._preventDefault(e);
                return false;
            }
        }).bind(this);
    }
    /**
     * @return {?}
     */
    WalkthroughService.prototype.disableScroll = function () {
        window.addEventListener('wheel', this._preventDefault, false);
        window.addEventListener('touchmove', this._preventDefault, false);
        document.addEventListener('keydown', this._preventDefaultForScrollKeys, false);
    };
    /**
     * @return {?}
     */
    WalkthroughService.prototype.enableScroll = function () {
        window.removeEventListener('wheel', this._preventDefault);
        window.removeEventListener('touchmove', this._preventDefault);
        document.removeEventListener('keydown', this._preventDefaultForScrollKeys);
    };
    /**
     * @param {?} element
     * @return {?}
     */
    WalkthroughService.prototype.scrollIntoViewIfOutOfView = function (element) {
        var /** @type {?} */ topOfPage = window.pageYOffset || document.documentElement.scrollTop || document.body.scrollTop;
        var /** @type {?} */ heightOfPage = this.getHeightOfPage();
        var /** @type {?} */ elementY = 0;
        var /** @type {?} */ elementH = 0;
        var /** @type {?} */ parent = element;
        while (parent && parent !== document.body) {
            elementY += parent.offsetTop;
            parent = (parent.offsetParent);
        }
        elementH = element.offsetHeight;
        if ((topOfPage + heightOfPage) < (elementY + elementH)) {
            element.scrollIntoView(false);
        }
        else if (elementY < topOfPage) {
            element.scrollIntoView(true);
        }
        else {
            // test of overflow element
            var /** @type {?} */ current = element;
            while (current && current !== document.body) {
                parent = this.getScrollParent(current);
                if (current.offsetTop + current.offsetHeight - parent.scrollTop > parent.offsetHeight ||
                    current.offsetLeft + current.offsetWidth - parent.scrollLeft > parent.offsetWidth) {
                    element.scrollIntoView();
                    break;
                }
                current = parent;
            }
        }
    };
    /**
     * @param {?} element
     * @return {?}
     */
    WalkthroughService.prototype.getScrollParent = function (element) {
        var /** @type {?} */ scrollParent;
        var /** @type {?} */ style = getComputedStyle(element);
        var /** @type {?} */ excludeStaticParent = style.position === 'absolute';
        if (style.position !== 'fixed') {
            var /** @type {?} */ parent_1 = element.parentElement;
            while (parent_1 && parent_1 !== document.body) {
                style = getComputedStyle(parent_1);
                if (!(excludeStaticParent && style.position === 'static') &&
                    this._overflowRegex.test(style.overflow + style.overflowY + style.overflowX)) {
                    scrollParent = parent_1;
                    break;
                }
                parent_1 = parent_1.parentElement;
            }
        }
        return scrollParent || document.body;
    };
    /**
     * @return {?}
     */
    WalkthroughService.prototype.getHeightOfPage = function () {
        return window.innerHeight || document.documentElement.clientHeight || document.body.clientHeight;
    };
    return WalkthroughService;
}());
WalkthroughService.decorators = [
    { type: _angular_core.Injectable },
];
/**
 * @nocollapse
 */
WalkthroughService.ctorParameters = function () { return []; };

var WalkthroughText = (function () {
    function WalkthroughText() {
        this.previous = 'Previous';
        this.next = 'Next';
        this.close = 'Close';
    }
    return WalkthroughText;
}());

var __extends$1 = (undefined && undefined.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @return {?}
 */
function throwWalkthroughContentAlreadyAttachedError() {
    throw Error('Attempting to attach walkthrough content after content is already attached');
}
var WalkthroughContainerComponent = (function (_super) {
    __extends$1(WalkthroughContainerComponent, _super);
    /**
     * @param {?} viewContainerRef
     * @param {?} _walkthroughService
     */
    function WalkthroughContainerComponent(viewContainerRef, _walkthroughService) {
        var _this = _super.call(this) || this;
        _this.viewContainerRef = viewContainerRef;
        _this._walkthroughService = _walkthroughService;
        // highlight zone
        _this.hasHighlightZone = false;
        _this.hasHighlight = false;
        _this.hasBackdrop = false;
        _this.hasGlow = false;
        // navigate
        _this.hasPrevious = false;
        _this.hasNext = false;
        _this.hasFinish = false;
        _this.hasCloseButton = false;
        _this.hasCloseAnywhere = true;
        // arrow
        _this.hasArrow = false;
        _this.arrowMarkerDist = 7;
        _this.arrowMargin = 30;
        // texts change / i18n
        _this.text = new WalkthroughText();
        return _this;
    }
    Object.defineProperty(WalkthroughContainerComponent.prototype, "id", {
        /**
         * @return {?}
         */
        get: function () {
            return this.parent ? this.parent.id + '-container' : null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WalkthroughContainerComponent.prototype, "hide", {
        /**
         * @return {?}
         */
        get: function () {
            return !this.show;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WalkthroughContainerComponent.prototype, "cursor", {
        /**
         * @return {?}
         */
        get: function () {
            return this.hasCloseAnywhere;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WalkthroughContainerComponent.prototype, "backdrop", {
        /**
         * @return {?}
         */
        get: function () {
            return !this.hasHighlightZone && this.hasBackdrop;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    WalkthroughContainerComponent.prototype.click = function () {
        if (this.hasCloseAnywhere) {
            this.close();
        }
    };
    /**
     * @param {?} event
     * @return {?}
     */
    WalkthroughContainerComponent.prototype.clickZone = function (event) {
        if (this.parent && this.hasClickable) {
            this.parent.focusClick(event, this);
        }
    };
    /**
     * Attach a ComponentPortal as content to this walkthrough container.
    \@param portal Portal to be attached as the walkthrough content.
     * @template T
     * @param {?} portal
     * @return {?}
     */
    WalkthroughContainerComponent.prototype.attachComponentPortal = function (portal) {
        if (this._portalHost.hasAttached()) {
            throwWalkthroughContentAlreadyAttachedError();
        }
        // this._savePreviouslyFocusedElement();
        return this._portalHost.attachComponentPortal(portal);
    };
    /**
     * Attach a TemplatePortal as content to this walkthrough container.
    \@param portal Portal to be attached as the walkthrough content.
     * @template C
     * @param {?} portal
     * @return {?}
     */
    WalkthroughContainerComponent.prototype.attachTemplatePortal = function (portal) {
        if (this._portalHost.hasAttached()) {
            throwWalkthroughContentAlreadyAttachedError();
        }
        // this._savePreviouslyFocusedElement();
        return this._portalHost.attachTemplatePortal(portal);
    };
    /**
     * @param {?} coordinate
     * @return {?}
     */
    WalkthroughContainerComponent.prototype.hightlightZone = function (coordinate) {
        var /** @type {?} */ zoneStyle = ((this.zone.nativeElement)).style;
        zoneStyle.left = coordinate.left + 'px';
        zoneStyle.top = coordinate.top + 'px';
        zoneStyle.width = coordinate.width + 'px';
        zoneStyle.height = coordinate.height + 'px';
    };
    /**
     * @param {?} element
     * @return {?}
     */
    WalkthroughContainerComponent.prototype.hightlightZoneStyling = function (element) {
        var /** @type {?} */ zoneStyle = ((this.zone.nativeElement)).style;
        if (this.radius) {
            if (Number(this.radius) === parseFloat(this.radius)) {
                // if is numeric, change in %
                zoneStyle.borderRadius = this.radius + '%';
            }
            else if (this.radius === 'auto') {
                // if mode auto
                var /** @type {?} */ elementStyle = window.getComputedStyle(element, null);
                // borderRadius work only on Chrome, use TopLeft, TopRight... for Firefox/Egde/IE
                zoneStyle.borderTopLeftRadius = elementStyle.borderTopLeftRadius;
                zoneStyle.borderTopRightRadius = elementStyle.borderTopRightRadius;
                zoneStyle.borderBottomLeftRadius = elementStyle.borderBottomLeftRadius;
                zoneStyle.borderBottomRightRadius = elementStyle.borderBottomRightRadius;
            }
            else {
                // if is numeric, change in %
                zoneStyle.borderRadius = this.radius;
            }
        }
        else {
            zoneStyle.borderRadius = '';
        }
    };
    /**
     * @param {?} coordinate
     * @param {?} position
     * @return {?}
     */
    WalkthroughContainerComponent.prototype.contentBlockPosition = function (coordinate, position) {
        var /** @type {?} */ element = (this.contentBlock.nativeElement);
        var /** @type {?} */ elementStyle = window.getComputedStyle(element, null);
        var /** @type {?} */ height = element.getBoundingClientRect().height
            + parseInt(elementStyle.marginTop, 10) + parseInt(elementStyle.marginBottom, 10);
        // position of content left/center/right
        element.style.right = '';
        element.style.left = '';
        if (position === 'left') {
            element.style.left = '0';
        }
        else if (position === 'center') {
            element.style.left = (window.innerWidth / 2 - element.getBoundingClientRect().width / 2) + 'px';
        }
        else if (position === 'right') {
            element.style.right = '0';
        }
        if (this.hasHighlightZone) {
            // for arrow possition
            var /** @type {?} */ contentBlockCoordinates = element.getBoundingClientRect();
            var /** @type {?} */ startLeft = contentBlockCoordinates.left + contentBlockCoordinates.width / 2;
            this._arrowPosition = startLeft > coordinate.left - this.arrowMargin
                && startLeft < coordinate.left + coordinate.width + this.arrowMargin
                ? 'topBottom' : 'leftRight';
            var /** @type {?} */ margin = this._arrowPosition === 'topBottom' ? this.arrowMargin : 0;
            // position of content top/bottom
            if (coordinate.top < height) {
                element.style.top = (coordinate.top + coordinate.height + margin) + 'px';
                this._contentPosition = 'bottom';
            }
            else {
                element.style.top = (coordinate.top - height - margin) + 'px';
                this._contentPosition = 'top';
            }
        }
        else {
            element.style.top = (this._walkthroughService.getHeightOfPage() / 2 - height / 2) + 'px';
        }
    };
    /**
     * @param {?} coordinate
     * @return {?}
     */
    WalkthroughContainerComponent.prototype.arrowPosition = function (coordinate) {
        var /** @type {?} */ contentBlockElement = (this.contentBlock.nativeElement);
        var /** @type {?} */ contentBlockCoordinates = contentBlockElement.getBoundingClientRect();
        var /** @type {?} */ startLeft = contentBlockCoordinates.left + contentBlockCoordinates.width / 2;
        var /** @type {?} */ startTop = contentBlockCoordinates.top + contentBlockCoordinates.height;
        var /** @type {?} */ centerTop;
        var /** @type {?} */ centerLeft;
        var /** @type {?} */ endLeft = coordinate.left;
        var /** @type {?} */ endTop = coordinate.top;
        if (this._contentPosition === 'bottom') {
            startTop -= contentBlockCoordinates.height;
        }
        if (this._arrowPosition === 'topBottom') {
            endLeft += coordinate.width / 2;
            if (this._contentPosition === 'bottom') {
                endTop += coordinate.height;
            }
            centerLeft = (startLeft + endLeft) / 2;
            centerTop = (startTop + endTop) / 2;
            this.arrowPath = "M" + startLeft + "," + startTop + " Q" + startLeft + "," + centerTop + " " + centerLeft + "," + centerTop + " "
                + ("Q" + endLeft + "," + centerTop + " " + endLeft + "," + endTop);
        }
        else {
            if (startLeft > coordinate.left) {
                endLeft += coordinate.width + this.arrowMarkerDist;
            }
            else {
                endLeft -= this.arrowMarkerDist;
            }
            endTop += coordinate.height / 2;
            this.arrowPath = "M" + startLeft + "," + startTop + " Q" + startLeft + "," + endTop + " " + endLeft + "," + endTop;
        }
    };
    /**
     * @return {?}
     */
    WalkthroughContainerComponent.prototype.open = function () {
        // show
        this.show = true;
        // scroll
        this._walkthroughService.disableScroll();
    };
    /**
     * @return {?}
     */
    WalkthroughContainerComponent.prototype.previous = function () {
        this.close();
        this.parent.loadPrevioustStep();
    };
    /**
     * @return {?}
     */
    WalkthroughContainerComponent.prototype.next = function () {
        this.close();
        this.parent.loadNextStep();
    };
    /**
     * @return {?}
     */
    WalkthroughContainerComponent.prototype.close = function () {
        // remove content
        this._portalHost.dispose();
        // hide
        this.show = false;
        this.parent.hide();
        // scroll
        this._walkthroughService.enableScroll();
    };
    return WalkthroughContainerComponent;
}(BasePortalHost));
WalkthroughContainerComponent.decorators = [
    { type: _angular_core.Component, args: [{
                selector: 'walkthrough-container',
                styles: [":host { display: block; position: fixed; z-index: 1; top: 0; left: 0; width: 100%; height: 100%; } :host.hide { display: none; } :host.cursor { cursor: pointer; } :host.backdrop { background-color: rgba(0, 0, 0, 0.6); } button { background: none; border: 0; color: #FFF; } .wkt-zone { position: absolute; } .wkt-zone.hide { display: none; } .wkt-zone.backdrop { box-shadow: 0 0 0 2000px rgba(0, 0, 0, 0.6); } .wkt-zone.glow { box-shadow: 0 0 4px 2px #FFFF66, 0 0 9px 0 #FFFF66, 0 0 36px #FFFF66; } .wkt-zone.clickable { cursor: pointer; } .wkt-zone.highlight { -webkit-animation: highlight .45s 4; animation: highlight .45s 4; } .wkt-container { position: relative; } .wkt-content-block { position: absolute; margin: 1em; padding: 6px; z-index: 1; color: #FFF; min-width: calc(320px - 2em); } .wkt-content-block.darken { background-color: rgba(0, 0, 0, 0.6); } .wkt-close + .wkt-content { margin-top: 1.3em; } .wkt-close { position: absolute; right: 1em; cursor: pointer; } .wkt-navigate { display: flex; flex-wrap: wrap; justify-content: center; } .wkt-navigate > button { padding: 6px; font-size: 120%; } .wkt-navigate > button:hover { cursor: pointer; text-decoration: underline; } .wkt-previous-link::before { content: '<< '; } .wkt-next-link::after { content: ' >>'; } svg { overflow: visible; position: absolute; top: -1px; left: -1px; border: 1px solid transparent; } #wkt-arrow > path { stroke-width: 0; } .wkt-arrow-path { stroke-width: 2px; fill: none; marker-end: url(#wkt-arrow); } @-webkit-keyframes highlight { 0% { background-color: none; } 50% { background-color: rgba(255, 255, 255, 0.8); } 100% { background-color: none; } } @keyframes highlight { 0% { background-color: none; } 50% { background-color: rgba(255, 255, 255, 0.8); } 100% { background-color: none; } } "],
                template: "<div class=\"wkt-container\"> <div class=\"wkt-zone\" #zone (click)=\"clickZone($event)\" [class.hide]=\"!hasHighlightZone\" [class.backdrop]=\"hasBackdrop\" [class.glow]=\"hasGlow\" [class.clickable]=\"hasClickable\" [class.highlight]=\"hasHighlight\"></div> <div class=\"wkt-content-block\" [class.darken]=\"contentStyle === 'draken'\" #contentBlock> <button type=\"button\" class=\"wkt-close\"  *ngIf=\"hasCloseButton\" (click)=\"close()\">✖</button> <div class=\"wkt-content\"> <p *ngIf=\"contentText\">{{contentText}}</p> <ng-template cdkPortalHost></ng-template> </div> <div class=\"wkt-navigate\" *ngIf=\"hasPrevious||hasNext||hasFinish\"> <button type=\"button\" class=\"wkt-previous-link\" *ngIf=\"hasPrevious\" (click)=\"previous()\">{{text.previous}}</button> <button type=\"button\" class=\"wkt-next-link\" *ngIf=\"hasNext\" (click)=\"next()\">{{text.next}}</button> <button type=\"button\" class=\"wkt-finish-link\" *ngIf=\"hasFinish\" (click)=\"close()\">{{text.close}}</button> </div> </div> <svg version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\" width=\"100%\" height=\"100%\" *ngIf=\"hasArrow\"> <defs> <marker id=\"wkt-arrow\" viewBox=\"0 0 10 10\" refX=\"8\" refY=\"5\" markerUnits=\"strokeWidth\" orient=\"auto\" markerWidth=\"10\" markerHeight=\"10\"> <polyline points=\"0,0 10,5 0,10 5,5\" [attr.fill]=\"arrowColor || '#FFF'\" /> </marker> </defs> <path class=\"wkt-arrow-path\" [attr.d]=\"arrowPath\" [attr.stroke]=\"arrowColor || '#FFF'\" /> </svg> </div> "
            },] },
];
/**
 * @nocollapse
 */
WalkthroughContainerComponent.ctorParameters = function () { return [
    { type: _angular_core.ViewContainerRef, },
    { type: WalkthroughService, },
]; };
WalkthroughContainerComponent.propDecorators = {
    '_portalHost': [{ type: _angular_core.ViewChild, args: [PortalHostDirective,] },],
    'content': [{ type: _angular_core.ViewChild, args: ['content',] },],
    'contentBlock': [{ type: _angular_core.ViewChild, args: ['contentBlock',] },],
    'zone': [{ type: _angular_core.ViewChild, args: ['zone',] },],
    'id': [{ type: _angular_core.HostBinding, args: ['attr.id',] },],
    'hide': [{ type: _angular_core.HostBinding, args: ['class.hide',] },],
    'cursor': [{ type: _angular_core.HostBinding, args: ['class.cursor',] },],
    'backdrop': [{ type: _angular_core.HostBinding, args: ['class.backdrop',] },],
    'click': [{ type: _angular_core.HostListener, args: ['click',] },],
};

var __assign = (undefined && undefined.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
var booleanValue = function (value) {
    return value === 'true' || value === true;
};
var nextUniqueId = 0;
var WalkthroughComponent = (function () {
    /**
     * @param {?} _componentFactoryResolver
     * @param {?} _applicationRef
     * @param {?} _injector
     * @param {?} _walkthroughService
     */
    function WalkthroughComponent(_componentFactoryResolver, _applicationRef, _injector, _walkthroughService) {
        this._componentFactoryResolver = _componentFactoryResolver;
        this._applicationRef = _applicationRef;
        this._injector = _injector;
        this._walkthroughService = _walkthroughService;
        this.typeSelector = 'element';
        this.contentStyle = 'draken';
        this._uid = "walkthrough-" + nextUniqueId++;
        this._show = false;
        this._hasHighlightAnimation = false;
        this._hasBackdrop = false;
        this._hasGlow = false;
        this._hasFinish = false;
        this._hasArrow = false;
        this._hasCloseButton = false;
        this._hasCloseAnywhere = true;
        this._justifyContent = 'left';
    }
    Object.defineProperty(WalkthroughComponent.prototype, "id", {
        /**
         * @return {?}
         */
        get: function () { return this._id; },
        /**
         * @param {?} value
         * @return {?}
         */
        set: function (value) { this._id = value || this._uid; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WalkthroughComponent.prototype, "justifyContent", {
        /**
         * @return {?}
         */
        get: function () {
            return this._justifyContent;
        },
        /**
         * @param {?} value
         * @return {?}
         */
        set: function (value) {
            if (this._justifyContent !== value) {
                this._justifyContent = value;
                if (WalkthroughComponent._walkthroughContainer && WalkthroughComponent._walkthroughContainer.instance) {
                    this._updateElementPositions(WalkthroughComponent._walkthroughContainer.instance);
                }
            }
            else {
                this._justifyContent = value;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WalkthroughComponent.prototype, "closeButton", {
        /**
         * @return {?}
         */
        get: function () {
            return this._hasCloseButton;
        },
        /**
         * @param {?} value
         * @return {?}
         */
        set: function (value) {
            this._hasCloseButton = booleanValue(value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WalkthroughComponent.prototype, "closeAnywhere", {
        /**
         * @return {?}
         */
        get: function () {
            return this._hasCloseAnywhere;
        },
        /**
         * @param {?} value
         * @return {?}
         */
        set: function (value) {
            this._hasCloseAnywhere = booleanValue(value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WalkthroughComponent.prototype, "showArrow", {
        /**
         * @return {?}
         */
        get: function () {
            return this._hasArrow;
        },
        /**
         * @param {?} value
         * @return {?}
         */
        set: function (value) {
            this._hasArrow = booleanValue(value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WalkthroughComponent.prototype, "finishStep", {
        /**
         * @return {?}
         */
        get: function () {
            return this._hasFinish;
        },
        /**
         * @param {?} value
         * @return {?}
         */
        set: function (value) {
            this._hasFinish = booleanValue(value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WalkthroughComponent.prototype, "focusHighlightAnimation", {
        /**
         * @return {?}
         */
        get: function () {
            return this._hasHighlightAnimation;
        },
        /**
         * @param {?} value
         * @return {?}
         */
        set: function (value) {
            this._hasHighlightAnimation = booleanValue(value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WalkthroughComponent.prototype, "focusBackdrop", {
        /**
         * @return {?}
         */
        get: function () {
            return this._hasBackdrop;
        },
        /**
         * @param {?} value
         * @return {?}
         */
        set: function (value) {
            this._hasBackdrop = booleanValue(value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WalkthroughComponent.prototype, "focusGlow", {
        /**
         * @return {?}
         */
        get: function () {
            return this._hasGlow;
        },
        /**
         * @param {?} value
         * @return {?}
         */
        set: function (value) {
            this._hasGlow = booleanValue(value);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    WalkthroughComponent.prototype.resize = function () {
        if (WalkthroughComponent._walkthroughContainer && this._show) {
            this._elementLocations();
        }
    };
    /**
     * @return {?}
     */
    WalkthroughComponent.prototype.ngOnInit = function () {
    };
    /**
     * @return {?}
     */
    WalkthroughComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        // init the Walkthrough element container
        if (!WalkthroughComponent._walkthroughContainer && !WalkthroughComponent._walkthroughContainerCreating) {
            WalkthroughComponent._walkthroughContainerCreating = true;
            setTimeout(function () {
                WalkthroughComponent._walkthroughContainer =
                    _this._appendComponentToBody(WalkthroughContainerComponent);
            }, 0);
        }
    };
    /**
     * @return {?}
     */
    WalkthroughComponent.prototype.open = function () {
        this._elementLocations();
    };
    /**
     * @return {?}
     */
    WalkthroughComponent.prototype.loadPrevioustStep = function () {
        var _this = this;
        setTimeout(function () {
            _this.previousStep.open();
        }, 0);
    };
    /**
     * @return {?}
     */
    WalkthroughComponent.prototype.loadNextStep = function () {
        var _this = this;
        setTimeout(function () {
            _this.nextStep.open();
        }, 0);
    };
    /**
     * @return {?}
     */
    WalkthroughComponent.prototype.show = function () {
        this._show = true;
    };
    /**
     * @return {?}
     */
    WalkthroughComponent.prototype.hide = function () {
        this._show = false;
    };
    /**
     * @template T
     * @param {?} component
     * @return {?}
     */
    WalkthroughComponent.prototype._appendComponentToBody = function (component) {
        // create a component reference
        var /** @type {?} */ componentRef = this._componentFactoryResolver.resolveComponentFactory(component).create(this._injector);
        // attach component to the appRef so that so that it will be dirty checked.
        this._applicationRef.attachView(componentRef.hostView);
        // get DOM element from component
        var /** @type {?} */ domElem = (((componentRef.hostView)).rootNodes[0]);
        document.body.appendChild(domElem);
        return componentRef;
    };
    /**
     * @template T
     * @param {?} componentOrTemplateRef
     * @param {?} walkthroughContainer
     * @return {?}
     */
    WalkthroughComponent.prototype._attachWalkthroughContent = function (componentOrTemplateRef, walkthroughContainer) {
        if (componentOrTemplateRef instanceof _angular_core.TemplateRef) {
            walkthroughContainer.attachTemplatePortal(new TemplatePortal(componentOrTemplateRef, /** @type {?} */ ((null))));
        }
        else {
            var /** @type {?} */ injectionTokens = new WeakMap();
            injectionTokens.set(WalkthroughContainerComponent, walkthroughContainer);
            var /** @type {?} */ injector = new PortalInjector(this._injector, injectionTokens);
            walkthroughContainer.attachComponentPortal(new ComponentPortal(componentOrTemplateRef, undefined, injector));
        }
    };
    /**
     * @return {?}
     */
    WalkthroughComponent.prototype._elementLocations = function () {
        this._getFocusElement();
        // get focus elements datas
        var /** @type {?} */ element = this._focusElement;
        if (element) {
            this._walkthroughService.scrollIntoViewIfOutOfView(element);
            this._offsetCoordinates = element.getBoundingClientRect();
            if (this.typeSelector === 'zone') {
                var /** @type {?} */ offsetEndCoordinatesEnd = this._focusElementEnd.getBoundingClientRect();
                this._offsetCoordinates.height = offsetEndCoordinatesEnd.top - this._offsetCoordinates.top
                    + offsetEndCoordinatesEnd.height;
                this._offsetCoordinates.width = offsetEndCoordinatesEnd.left - this._offsetCoordinates.left
                    + offsetEndCoordinatesEnd.width;
            }
        }
        else {
            this._offsetCoordinates = null;
        }
        this._setFocus();
    };
    /**
     *
     * @return {?}
     */
    WalkthroughComponent.prototype._getFocusElement = function () {
        var /** @type {?} */ focusElements = this.focusElementSelector
            ? (document.querySelectorAll(this.focusElementSelector))
            : null;
        // getting focus element
        if (focusElements && focusElements.length > 0) {
            if (focusElements.length > 1) {
                // Multiple items fit selector, displaying first visible as focus item in 'element' mode
                var /** @type {?} */ l = focusElements.length;
                for (var /** @type {?} */ i = 0; i < l; i++) {
                    // offsetHeight not of 0 means visible
                    if (focusElements[i].offsetHeight) {
                        this._focusElement = focusElements[i];
                        i = focusElements.length;
                        break;
                    }
                }
                // if typeSelector is by zone, get also the last element
                if (this.typeSelector === 'zone') {
                    for (var /** @type {?} */ i = l - 1; i >= 0; i--) {
                        // offsetHeight not of 0 means visible
                        if (focusElements[i].offsetHeight) {
                            this._focusElementEnd = focusElements[i];
                            i = focusElements.length;
                            break;
                        }
                    }
                    // this the zone this just a unique element, change mode for 'element'
                    if (this._focusElement === this._focusElementEnd) {
                        this.typeSelector = 'element';
                    }
                }
            }
            else {
                this._focusElement = focusElements[0];
                this.typeSelector = 'element';
            }
        }
        else {
            this._focusElement = null;
        }
    };
    /**
     * get instance, hightlight the focused element et show the template
     * @return {?}
     */
    WalkthroughComponent.prototype._setFocus = function () {
        var _this = this;
        var /** @type {?} */ instance = WalkthroughComponent._walkthroughContainer.instance;
        if (instance) {
            if (this._focusElement && instance.zone) {
                instance.hightlightZone(this._offsetCoordinates);
            }
            if (!this._show) {
                this._attachContentTemplate();
                this._initContentTemplate(instance);
            }
            setTimeout(function () {
                instance.hightlightZoneStyling(_this._focusElement);
                _this._updateElementPositions(instance);
            }, 0);
        }
    };
    /**
     * @param {?} instance
     * @return {?}
     */
    WalkthroughComponent.prototype._updateElementPositions = function (instance) {
        var _this = this;
        setTimeout(function () {
            instance.contentBlockPosition(_this._offsetCoordinates, _this._justifyContent);
            if (_this._focusElement !== null && _this._hasArrow) {
                instance.arrowPosition(_this._offsetCoordinates);
            }
        }, 0);
    };
    /**
     * Attache the template in the contener, if a template is linked.
     * @return {?}
     */
    WalkthroughComponent.prototype._attachContentTemplate = function () {
        if (this.contentTemplate) {
            this._attachWalkthroughContent(this.contentTemplate, WalkthroughComponent._walkthroughContainer.instance);
        }
    };
    /**
     * init all datas of the contenaire
     * @param {?} instance
     * @return {?}
     */
    WalkthroughComponent.prototype._initContentTemplate = function (instance) {
        var /** @type {?} */ hasHighlightZone = this._focusElement !== null;
        instance.parent = this;
        instance.open();
        instance.hasHighlightZone = hasHighlightZone;
        instance.hasClickable = hasHighlightZone && typeof this.focusClick === 'function';
        instance.hasHighlight = hasHighlightZone && this._hasHighlightAnimation;
        instance.hasBackdrop = this._hasBackdrop;
        instance.hasGlow = hasHighlightZone && this._hasGlow;
        instance.hasPrevious = !!this.previousStep;
        instance.hasNext = !!this.nextStep;
        instance.hasCloseButton = this._hasCloseButton;
        instance.hasCloseAnywhere = this._hasCloseAnywhere;
        instance.hasFinish = this._hasFinish;
        instance.hasArrow = hasHighlightZone && this._hasArrow;
        instance.arrowColor = this.arrowColor;
        instance.radius = this.radius;
        instance.contentText = this.contentText;
        instance.contentStyle = this.contentStyle;
        instance.text = this.texts
            ? __assign({}, new WalkthroughText(), this.texts) : new WalkthroughText();
        this.show();
    };
    return WalkthroughComponent;
}());
WalkthroughComponent._walkthroughContainerCreating = false;
WalkthroughComponent.decorators = [
    { type: _angular_core.Component, args: [{
                selector: 'ng-walkthrough',
                template: ''
            },] },
];
/**
 * @nocollapse
 */
WalkthroughComponent.ctorParameters = function () { return [
    { type: _angular_core.ComponentFactoryResolver, },
    { type: _angular_core.ApplicationRef, },
    { type: _angular_core.Injector, },
    { type: WalkthroughService, },
]; };
WalkthroughComponent.propDecorators = {
    'focusElementSelector': [{ type: _angular_core.Input },],
    'typeSelector': [{ type: _angular_core.Input },],
    'focusClick': [{ type: _angular_core.Input },],
    'radius': [{ type: _angular_core.Input },],
    'previousStep': [{ type: _angular_core.Input },],
    'nextStep': [{ type: _angular_core.Input },],
    'texts': [{ type: _angular_core.Input },],
    'contentTemplate': [{ type: _angular_core.Input },],
    'contentText': [{ type: _angular_core.Input },],
    'contentStyle': [{ type: _angular_core.Input },],
    'arrowColor': [{ type: _angular_core.Input },],
    'id': [{ type: _angular_core.Input },],
    'justifyContent': [{ type: _angular_core.Input },],
    'closeButton': [{ type: _angular_core.Input },],
    'closeAnywhere': [{ type: _angular_core.Input },],
    'showArrow': [{ type: _angular_core.Input },],
    'finishStep': [{ type: _angular_core.Input },],
    'focusHighlightAnimation': [{ type: _angular_core.Input },],
    'focusBackdrop': [{ type: _angular_core.Input },],
    'focusGlow': [{ type: _angular_core.Input },],
    'resize': [{ type: _angular_core.HostListener, args: ['window:resize',] },],
};

var WalkthroughFlowComponent = (function () {
    function WalkthroughFlowComponent() {
    }
    /**
     * @return {?}
     */
    WalkthroughFlowComponent.prototype.start = function () {
    };
    return WalkthroughFlowComponent;
}());
WalkthroughFlowComponent.decorators = [
    { type: _angular_core.Component, args: [{
                selector: 'ng-walkthrough-flow',
                template: ''
            },] },
];
/**
 * @nocollapse
 */
WalkthroughFlowComponent.ctorParameters = function () { return []; };

var WalkthroughModule = (function () {
    function WalkthroughModule() {
    }
    /**
     * @return {?}
     */
    WalkthroughModule.forRoot = function () {
        return {
            ngModule: WalkthroughModule,
            providers: []
        };
    };
    return WalkthroughModule;
}());
WalkthroughModule.decorators = [
    { type: _angular_core.NgModule, args: [{
                declarations: [
                    WalkthroughFlowComponent,
                    WalkthroughComponent,
                    WalkthroughContainerComponent
                ],
                imports: [
                    _angular_common.CommonModule,
                    PortalModule
                ],
                exports: [
                    WalkthroughFlowComponent,
                    WalkthroughComponent,
                    WalkthroughContainerComponent
                ],
                entryComponents: [
                    WalkthroughContainerComponent
                ],
                providers: [
                    WalkthroughService
                ]
            },] },
];
/**
 * @nocollapse
 */
WalkthroughModule.ctorParameters = function () { return []; };

/**
 * Generated bundle index. Do not edit.
 */

exports.WalkthroughComponent = WalkthroughComponent;
exports.throwWalkthroughContentAlreadyAttachedError = throwWalkthroughContentAlreadyAttachedError;
exports.WalkthroughContainerComponent = WalkthroughContainerComponent;
exports.WalkthroughModule = WalkthroughModule;
exports.WalkthroughText = WalkthroughText;
exports.ɵb = WalkthroughFlowComponent;
exports.ɵa = WalkthroughService;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=angular-walkthrough.umd.js.map
